@@ -55,6 +55,10 @@ def list_instances(
     if name is not None:
         cmd.append(name)
 
+    # Does the user want to see the command printed?
+    if not (quiet or self.quiet):
+        bot.info(" ".join(cmd))
+
     output = run_command(cmd, quiet=True, sudo=sudo, sudo_options=sudo_options)
     instances = []
 
@@ -77,12 +81,12 @@ def list_instances(
 
                 # Otherwise, add instances to the listing
                 new_instance = self.instance(
-                    pid=i["pid"],
-                    ip_address=i["ip"],
-                    name=i["instance"],
-                    log_err_path=i["logErrPath"],
-                    log_out_path=i["logOutPath"],
-                    image=i.get("img", None),
+                    pid=i.get("pid"),
+                    ip_address=i.get("ip"),
+                    name=i.get("instance") or i.get("daemon_name"),
+                    log_err_path=i.get("logErrPath"),
+                    log_out_path=i.get("logOutPath"),
+                    image=i.get("img") or i.get("container_image"),
                     start=False,
                 )
 
@@ -126,6 +130,11 @@ def stopall(self, sudo=False, quiet=True, singularity_options=None):
 
     cmd = self._init_command(subgroup, singularity_options)
     cmd = cmd + ["--all"]
+
+    # Does the user want to see the command printed?
+    if not (quiet or self.quiet):
+        bot.info(" ".join(cmd))
+
     output = run_command(cmd, sudo=sudo, quiet=quiet)
 
     if output["return_code"] != 0:
